@@ -148,7 +148,7 @@ void Board::setAppearance(const AppearanceDialog& dialog)
 	QPalette palette = dialog.colors();
 	graphics_layer->setClearColor(palette.color(QPalette::Base).darker(150));
 	setPalette(palette);
-	for (Piece* piece : qAsConst(m_pieces)) {
+	for (Piece* piece : std::as_const(m_pieces)) {
 		piece->setSelected(piece->isSelected());
 	}
 }
@@ -419,13 +419,13 @@ void Board::saveGame()
 		.arg(m_scene.width())
 		.arg(m_scene.height()));
 
-	for (Piece* piece : qAsConst(m_pieces)) {
+	for (Piece* piece : std::as_const(m_pieces)) {
 		piece->save(xml);
 	}
-	for (Piece* piece : qAsConst(m_selected_pieces)) {
+	for (Piece* piece : std::as_const(m_selected_pieces)) {
 		piece->save(xml);
 	}
-	for (Piece* piece : qAsConst(m_active_pieces)) {
+	for (Piece* piece : std::as_const(m_active_pieces)) {
 		piece->save(xml);
 	}
 
@@ -454,7 +454,7 @@ void Board::retrievePieces()
 
 	// Move all pieces to center of view
 	std::shuffle(pieces.begin(), pieces.end(), m_random);
-	for (Piece* piece : qAsConst(pieces)) {
+	for (Piece* piece : std::as_const(pieces)) {
 		m_pieces.append(piece);
 		piece->setPosition(m_pos - QRect(QPoint(0,0), piece->boundingRect().size()).center());
 		piece->setSelected(false);
@@ -1264,7 +1264,7 @@ void Board::updateArray(Region& region, const QRect& rect, int z)
 void Board::updateSceneRectangle()
 {
 	m_scene = QRect(0,0,0,0);
-	for (Piece* piece : qAsConst(m_pieces)) {
+	for (Piece* piece : std::as_const(m_pieces)) {
 		updateSceneRectangle(piece);
 	}
 }
