@@ -33,9 +33,9 @@ public:
 	 * Load the stored language into the application; defaults to system language.
 	 *
 	 * @param appname application name to prepend to translation filenames
-	 * @param datadirs locations to search for directory containing translations
+	 * @param datadir location to search for translations
 	 */
-	static void loadTranslator(const QString& appname, const QStringList& datadirs = QStringList());
+	static void loadTranslator(const QString& appname, const QString& datadir);
 
 	/**
 	 * Fetch native language name for QLocale name.
@@ -45,7 +45,7 @@ public:
 	 */
 	static QString languageName(const QString& language);
 
-public slots:
+public Q_SLOTS:
 	/** Override parent function to store application language. */
 	void accept() override;
 
