@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2008, 2010, 2011, 2012, 2015, 2016, 2018 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2008-2020 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "message.h"
 
@@ -32,12 +19,12 @@ int powerOfTwo(int value);
 
 //-----------------------------------------------------------------------------
 
-Message::Message(QWidget* parent) :
-	QObject(parent),
-	m_parent(parent),
-	m_image(nullptr),
-	m_visible(false),
-	m_color(Qt::white)
+Message::Message(QWidget* parent)
+	: QObject(parent)
+	, m_parent(parent)
+	, m_image(nullptr)
+	, m_visible(false)
+	, m_color(Qt::white)
 {
 	m_hide_timer = new QTimer(this);
 	m_hide_timer->setInterval(2000);
@@ -45,7 +32,7 @@ Message::Message(QWidget* parent) :
 	connect(m_hide_timer, &QTimer::timeout, this, &Message::hide);
 
 	m_fade_timer = new QTimeLine(160, this);
-	m_fade_timer->setCurveShape(QTimeLine::LinearCurve);
+	m_fade_timer->setEasingCurve(QEasingCurve::Linear);
 	m_fade_timer->setDirection(QTimeLine::Backward);
 	m_fade_timer->setFrameRange(0, 10);
 	m_fade_timer->setUpdateInterval(16);
